@@ -1,11 +1,11 @@
 """
-github3
+betamax
 =======
 
-See http://github3py.rtfd.org/ for documentation.
+See http://betamax.rtfd.org/ for documentation.
 
-:copyright: (c) 2012-2013 by Ian Cordasco
-:license: Modified BSD, see LICENSE for more details
+:copyright: (c) 2013 by Ian Cordasco
+:license: Apache 2.0, see LICENSE for more details
 
 """
 
@@ -16,7 +16,7 @@ from betamax.matchers import BaseMatcher
 __all__ = [BetamaxError, Betamax, BaseMatcher]
 __author__ = 'Ian Cordasco'
 __copyright__ = 'Copyright 2013 Ian Cordasco'
-__license__ = 'Modified BSD'
+__license__ = 'Apache 2.0'
 __title__ = 'betamax'
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 __version_info__ = tuple(int(i) for i in __version__.split('.'))
