@@ -309,8 +309,13 @@ class MockHTTPResponse(object):
         # Thanks to Python 3, we have to use the slightly more awful API below
         # mimetools was deprecated so we have to use email.message.Message
         # which takes no arguments in its initializer.
-        self.msg = email.message.Message()
+        self.msg = EmailMessage()
         self.msg.set_payload(h)
 
     def isclosed(self):
         return False
+
+
+class EmailMessage(email.message.Message):
+    def getheaders(self, value, *args):
+        return self.get(value, *args)
